{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ts-ZA",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mus",
    "Bir",
    "Har",
    "Ne",
    "Tlh",
    "Mug",
    "Son",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Musumbhunuku",
    "Ravumbirhi",
    "Ravunharhu",
    "Ravumune",
    "Ravuntlhanu",
    "Mugqivela",
    "Sonta",
  ],
  day_stand_alone_abbreviated => [
    "Mus",
    "Bir",
    "Har",
    "Ne",
    "Tlh",
    "Mug",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Musumbhunuku",
    "Ravumbirhi",
    "Ravunharhu",
    "Ravumune",
    "Ravuntlhanu",
    "Mugqivela",
    "Sonta",
  ],
  era_abbreviated => [
    "BC",
    "CE",
  ],
  era_narrow => [
    "BC",
    "CE",
  ],
  era_wide => [
    "BC",
    "CE",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %-e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%a %-e %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Tsonga",
  month_format_abbreviated => [
    "Sun",
    "Yan",
    "Kul",
    "Dzi",
    "Mud",
    "Kho",
    "Maw",
    "Mha",
    "Ndz",
    "Nhl",
    "Huk",
    "N\N{U+2019}w",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Sunguti",
    "Nyenyenyani",
    "Nyenyankulu",
    "Dzivamisoko",
    "Mudyaxihi",
    "Khotavuxika",
    "Mawuwani",
    "Mhawuri",
    "Ndzhati",
    "Nhlangula",
    "Hukuri",
    "N\N{U+2019}wendzamhala",
  ],
  month_stand_alone_abbreviated => [
    "Sun",
    "Yan",
    "Kul",
    "Dzi",
    "Mud",
    "Kho",
    "Maw",
    "Mha",
    "Ndz",
    "Nhl",
    "Huk",
    "N\N{U+2019}w",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Sunguti",
    "Nyenyenyani",
    "Nyenyankulu",
    "Dzivamisoko",
    "Mudyaxihi",
    "Khotavuxika",
    "Mawuwani",
    "Mhawuri",
    "Ndzhati",
    "Nhlangula",
    "Hukuri",
    "N\N{U+2019}wendzamhala",
  ],
  name => "Tsonga South Africa",
  native_language => undef,
  native_name => "",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kotara yo sungula",
    "Kotara ya vumbirhi",
    "Kotara ya vunharhu",
    "Kotara ya vumune",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kotara yo sungula",
    "Kotara ya vumbirhi",
    "Kotara ya vunharhu",
    "Kotara ya vumune",
  ],
  script => undef,
  territory => "South Africa",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 47,
}
